.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :caption: Modules
   :hidden:

   modules/bandmap
   modules/mdcs
   modules/selfenergies
   modules/distributions
   modules/functions
   modules/plotting
   modules/settings_parameters
   modules/settings_plots

.. toctree::
   :caption: Tutorials
   :hidden:

   notebooks/verification
   notebooks/srtio3
   notebooks/graphene

.. toctree::
   :caption: More
   :hidden:

   genindex